Index: src/compiler/linkage.h |
diff --git a/src/compiler/linkage.h b/src/compiler/linkage.h |
index 8596327290b0643340868475e0a9580ad5ddb964..762e2a2b0ad2fa5b4b88c6a8cebe96c7772e6b21 100644 |
--- a/src/compiler/linkage.h |
+++ b/src/compiler/linkage.h |
@@ -144,9 +144,10 @@ class CallDescriptor final : public ZoneObject { |
public: |
// Describes the kind of this call, which determines the target. |
enum Kind { |
- kCallCodeObject, // target is a Code object |
- kCallJSFunction, // target is a JSFunction object |
- kCallAddress // target is a machine pointer |
+ kCallCodeObject, // target is a Code object |
+ kCallWasmFunction, // target is a Wasm function identified by its index |
+ kCallJSFunction, // target is a JSFunction object |
+ kCallAddress // target is a machine pointer |
}; |
enum Flag { |